@@ -28,9 +28,11 @@ STRUCTURE_MATRIX = np.array([np.identity(3),
                               [0, 0.5, 0.5],
                               [0.5, 0, 0.5]]])
 
-# 0 is coprime only with 1
+
 def coprime(a, b):
-    return gcd(a,b) in (0, 1)
+    """0 is coprime only with 1"""
+
+    return gcd(a, b) in (0, 1)
 
 
 def get_cubic_sigma(hkl, m, n=1):
@@ -40,14 +42,15 @@ def get_cubic_sigma(hkl, m, n=1):
         sigma /= 2
     return (sigma if sigma > 1 else None)
 
+
 def get_cubic_theta(hkl, m, n=1):
-    h,k,l = hkl
+    h, k, l = hkl
     sqsum = h*h + k*k + l*l
     assert sqsum > 0
     if m > 0:
         return 2 * atan(np.sqrt(sqsum) * n / m)
     else:
-        return pi
+        return np.pi
 
 
 def get_theta_m_n_list(hkl, sigma, verbose=False):
@@ -78,26 +81,27 @@ def get_theta_m_n_list(hkl, sigma, verbose=False):
 
 
 def rodrigues(a, angle, verbose=False):
-    "use Rodrigues' rotation formula to get rotation matrix"
+    """use Rodrigues' rotation formula to get rotation matrix"""
     a = np.array(a, dtype=float)
-    a /= np.sqrt(np.inner(a, a)) # make unit vector
-    #assert abs(sin_angle - sin(acos(cos_angle))) < 1e-6
+    a /= np.sqrt(np.inner(a, a))  # make unit vector
+    # assert abs(sin_angle - sin(acos(cos_angle))) < 1e-6
     if verbose:
-        print ("rotation angle:", np.degrees(angle))
-        print ("rotation axis:", a)
-    omega = np.array([[   0., -a[2],  a[1]],
-                   [ a[2],    0., -a[0]],
-                   [-a[1],  a[0],    0.]])
-    rm = (np.identity(3) + omega * np.sin(angle)
-                            + np.dot(omega, omega) * (1 - np.cos(angle)))
+        print("rotation angle:", np.degrees(angle))
+        print("rotation axis:", a)
+    omega = np.array([[0., -a[2], a[1]],
+                     [a[2], 0., -a[0]],
+                     [-a[1], a[0], 0.]])
+    rm = (np.identity(3) + omega * np.sin(angle) + np.dot(omega, omega) * (1 - np.cos(angle)))
     if verbose:
         print("rotation matrix:", rm)
     return rm
 
+
 def is_integer(a, epsilon=1e-7):
-    "return true if numpy Float array consists off all integers"
+    """return true if numpy Float array consists off all integers"""
     return (np.abs(a - np.round(a)) < epsilon).all()
 
+
 def get_smallest_multiplier(a, max_n=1000):
     """return the smallest positive integer n such that matrix a multiplied
        by n is an integer matrix
@@ -105,7 +109,8 @@ def get_smallest_multiplier(a, max_n=1000):
     for i in range(1, max_n):
         if is_integer(i*a):
             return i
-        
+
+
 def plus_minus_gen(start, end):
     """
     Generate a list of plus and minus alternating integers
@@ -113,7 +118,9 @@ def plus_minus_gen(start, end):
     for i in range(start, end):
         yield i
         yield -i
-def get_csl_matrix(sigma, rotate_matrix):
+
+
+def get_csl_matrix(sigma, rotate_matrix, centering=None):
     """  Find matrix that determines the coincidence site lattice for cubic structures.
 
     Based on H. Grimmer et al., Acta Cryst. (1974) A30, 197
@@ -123,10 +130,11 @@ def get_csl_matrix(sigma, rotate_matrix):
     ----------
     sigma: float:
         CSL sigma
-    R: numpy array
+    rotate_matrix: numpy array
         rotation matrix
     centering: string
         "f" for f.c.c., "b" for b.c.c. and None for p.c.
+
     Returns
     -------
     matrix: numpy array
@@ -136,13 +144,13 @@ def get_csl_matrix(sigma, rotate_matrix):
     s = STRUCTURE_MATRIX[0]
     for u in UNIMODULAR_MATRIX:
         t = np.eye(3) - np.dot(np.dot(np.dot(u, np.linalg.inv(s)),  np.linalg.inv(rotate_matrix)), s)
-        if abs( np.linalg.det(t)) > 1e-6:
+        if abs(np.linalg.det(t)) > 1e-6:
             break
-    o_lattice = np.round( np.linalg.inv(t), 12)
-    n = np.round(sigma /  np.linalg.det(o_lattice), 6)
+    o_lattice = np.round(np.linalg.inv(t), 12)
+    n = np.round(sigma / np.linalg.det(o_lattice), 6)
     csl_matrix = o_lattice_to_csl(o_lattice, n)
     return csl_matrix
-    
+
 
 def o_lattice_to_csl(o_lattice, n):
     """
@@ -288,9 +296,8 @@ def orthogonalize_csl(csl, axis):
             if new_vec[1] == new_vec[2]:
                 new_vec = [new_vec[0], new_vec[1], new_vec[3]]
             else:
-                new_vec = reduce_vector([new_vec[0] * new_vec[2],
-                                         new_vec[1] * new_vec[2],
-                                         new_vec[3] * new_vec[1]])
+                new_vec = new_vec  # Todo: where is reduce_vector function
+                # reduce_vector([new_vec[0] * new_vec[2], new_vec[1] * new_vec[2], new_vec[3] * new_vec[1]])
         assert is_integer(new_vec)
         return new_vec * vec_sign
 
@@ -315,11 +322,13 @@ def orthogonalize_csl(csl, axis):
                 raise ValueError("Non-orthogonal basis: %s" % csl)
     return csl.round().astype(int)
 
+
 def find_smallest_real_multiplier(a, max_n=1000):
     """return the smallest positive real f such that matrix `a' multiplied
        by f is an integer matrix
     """
-    # |the smallest non-zero element|
+
+    # the smallest non-zero element|
     m = min(abs(i) for i in a if abs(i) > 1e-9)
     for i in range(1, max_n):
         t = i / float(m)
@@ -327,7 +336,7 @@ def find_smallest_real_multiplier(a, max_n=1000):
             return t
     raise ValueError("Sorry, we can't make this matrix integer:\n%s" % a)
 
+
 def scale_to_integers(v):
     """scale to integer"""
     return np.array(v * find_smallest_real_multiplier(v)).round().astype(int)
-
